@@ -1,6 +1,6 @@
 package PDF::API2::Resource::ColorSpace::Indexed::ACTFile;
 
-our $VERSION = '2.020'; # VERSION
+our $VERSION = '2.022'; # VERSION
 
 use base 'PDF::API2::Resource::ColorSpace::Indexed';
 
@@ -11,7 +11,7 @@ no warnings qw[ deprecated recursion uninitialized ];
 
 =head1 NAME
 
-PDF::API2::Resource::ColorSpace::Indexed::ACTFile
+PDF::API2::Resource::ColorSpace::Indexed::ACTFile - Adobe Color Table support
 
 =head1 METHODS
 
@@ -21,7 +21,7 @@ PDF::API2::Resource::ColorSpace::Indexed::ACTFile
 
 Returns a new colorspace object created from an adobe color table file (ACT/8BCT).
 See
-Adobe Photoshop 6.0 --
+Adobe Photoshop(R) 6.0 --
 File Formats Specification Version 6.0 Release 2,
 November 2000
 for details.
@@ -58,4 +58,8 @@ sub new {
     return($self);
 }
 
+=back
+
+=cut
+
 1;
